/*
 * Copyright (c) 2018 Arnaud Ysmal.  All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
 * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

package kendall2

import (
	"jsonresume/model"
	"jsonresume/themes"
	"path"
	"text/template"
)

const (
	packageDirectory = "themes/kendall2"
	fileCSS          = "style.css"
	fileCSSPrint     = "print.css"
	fileTemplate     = "resume.template"
)

var Theme = themes.Theme{
	Name:      "kendall2",
	Directory: packageDirectory,
	Functions: template.FuncMap{
		"css":      getCSS,
		"printcss": getPrintCSS,
		"md2html":  md2html,
	},
}

func init() {
	t, _ := Asset(path.Join(packageDirectory, fileTemplate))
	Theme.Template = string(t)
	(&Theme).Register()
}

func getCSS() string {
	r, _ := Asset(path.Join(packageDirectory, fileCSS))
	return string(r)
}

func getPrintCSS() string {
	r, _ := Asset(path.Join(packageDirectory, fileCSSPrint))
	return string(r)
}

func md2html(s string) string {
	return model.MarkdownURLRegexp.ReplaceAllString(s, `<a href="$2" target="_blank">$1</a>`)
}
